<?php

/**
 * This software is intended for use with Oxwall Free Community Software http://www.oxwall.org/ and is
 * licensed under The BSD license.

 * ---
 * Copyright (c) 2009, Skalfa LLC
 * All rights reserved.

 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *  - Redistributions of source code must retain the above copyright notice, this list of conditions and
 *  the following disclaimer.
 *
 *  - Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 *  the following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *  - Neither the name of the Skalfa LLC nor the names of its contributors may be used to endorse or promote products
 *  derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * @author Aybat Duyshokov <duyshokov@gmail.com>
 * @package ow_plugins.blogs.controllers
 * @since 1.0
 */
class BLOGS_CTRL_Save extends OW_ActionController
{

    public function index( $params = array() )
    {

        if ( !OW::getUser()->isAuthenticated() )
        {
            throw new AuthenticateException();
        }

        if ( !OW::getUser()->isAuthorized('blogs', 'add') )
        {
            $this->setTemplate(OW::getPluginManager()->getPlugin('base')->getCtrlViewDir() . 'authorization_failed.html');

            return;
        }

        $plugin = OW::getPluginManager()->getPlugin('blogs');
        OW::getNavigation()->activateMenuItem(OW_Navigation::MAIN, 'blogs', 'main_menu_item');


        $this->setPageHeading(OW::getLanguage()->text('blogs', 'save_page_heading'));
        $this->setPageHeadingIconClass('ow_ic_write');

        $id = empty($params['id']) ? 0 : $params['id'];

        $service = PostService::getInstance(); /* @var $service PostService */

        $tagService = BOL_TagService::getInstance();

        if ( intval($id) > 0 )
        {
            $post = $service->findById($id);
        }
        else
        {
            $post = new Post();

            $post->setAuthorId(OW::getUser()->getId());
        }

        $textF = new BLOGS_TextFormatter();

        $this->addComponent('textf', $textF);

        $form = new SaveForm($post);

        if ( OW::getRequest()->isPost() &&
            (!empty($_POST['command']) && in_array($_POST['command'], array('draft', 'publish')) ) &&
            $form->isValid($_POST) )
        {
            $form->process($this);
            OW::getApplication()->redirect(OW::getRouter()->urlForRoute('post-save-edit', array('id' => $post->getId())));
        }

        $this->addForm($form);

        $this->assign('info', array('dto' => $post));
    }

    public function delete( $params )
    {
        /*
          @var $service PostService
         */
        $service = PostService::getInstance();

        $id = $params['id'];

        $dto = $service->findById($id);

        if ( !empty($dto) )
        {
            $service->delete($dto);
            if ( OW::getPluginManager()->isPluginActive('activity') )
            {
                ACTIVITY_BOL_Service::getInstance()->deleteAction(null, 'blog-post-add', $id);
            }

            BOL_FlagService::getInstance()->deleteByTypeAndEntityId('blog_post', $id);
        }

        if ( $_GET['back-to'] )
        {
            $this->redirect($_GET['back-to']);
        }

        $author = BOL_UserService::getInstance()->findUserById($dto->authorId);

        $this->redirect(OW::getRouter()->urlForRoute('user-blog', array('user' => $author->getUsername())));
    }
}

class SaveForm extends Form
{
    /**
     * 
     * @var Post
     */
    private $post;

    public function __construct( Post $post, $tags = array() )
    {
        parent::__construct('save');

        $this->post = $post;

        $this->setMethod('post');

        $titleTextField = new TextField('title');

        $this->addElement(
            $titleTextField->setLabel(OW::getLanguage()->text('blogs', 'save_form_lbl_title'))->setValue($post->getTitle())->setRequired(true));

        $postTextArea = new Textarea('post');

        $postTextArea->setId('ff');

        $this->addElement(
            $postTextArea->setLabel(OW::getLanguage()->text('blogs', 'save_form_lbl_post'))->setValue($post->getPost())->setRequired(true));

        $draftSubmit = new Submit('draft');
        $draftSubmit->addAttribute('onclick', "$('#save_post_command').attr('value', 'draft');");

        if ( $post->getId() != null && !$post->isDraft() )
        {
            $text = OW::getLanguage()->text('blogs', 'change_status_draft');
        }
        else
        {
            $text = OW::getLanguage()->text('blogs', 'sava_draft');
        }

        $this->addElement($draftSubmit->setValue($text));

        if ( $post->getId() != null && !$post->isDraft() )
        {
            $text = OW::getLanguage()->text('blogs', 'update');
        }
        else
        {
            $text = OW::getLanguage()->text('blogs', 'save_publish');
        }

        $publishSubmit = new Submit('publish');
        $publishSubmit->addAttribute('onclick', "$('#save_post_command').attr('value', 'publish');");

        $this->addElement($publishSubmit->setValue($text));

        $tagService = BOL_TagService::getInstance();

        $tags = array();

        if ( intval($this->post->getId()) > 0 )
        {
            $arr = $tagService->findEntityTags($this->post->getId(), 'blog-post');

            foreach ( (!empty($arr) ? $arr : array() ) as $dto )
            {
                $tags[] = $dto->getLabel();
            }
        }

        $tf = new TagsField('tf', $tags);

        $tf->setLabel(OW::getLanguage()->text('blogs', 'tags_field_label'));

        $this->addElement($tf);
    }

    public function process( $ctrl )
    {
        $data = $this->getValues();
        
        $data['title'] = UTIL_HtmlTag::stripJs($data['title']);
        $data['post'] = UTIL_HtmlTag::stripJs($data['post']);

        $service = PostService::getInstance(); /* @var $postDao PostService */
        
        /* @var $post Post */
        $this->post->setTitle($data['title'])->
            setPost($data['post'])->
            setIsDraft($_POST['command'] == 'draft');

        $tags = array();

        $isCreate = empty($this->post->id);

        if ($isCreate)
        {
            $this->post->setTimestamp(time());    
        }
        
        $service->save($this->post);

        if ( intval($this->post->getId()) > 0 )
        {
            $tags = TagsField::getTags($data['tf']);
        }

        $tagService = BOL_TagService::getInstance();

        $tagService->updateEntityTags($this->post->getId(), 'blog-post', $tags);
        $dontAddActivity = !$isCreate || $this->post->isDraft() || !OW::getPluginManager()->isPluginActive('activity');
        if ( $dontAddActivity )
        {
            if ( !$this->post->isDraft() )
            {
                $ctrl->redirect(OW::getRouter()->urlForRoute('post', array('id' => $this->post->getId())));
            }

            return;
        }

        $action = new ACTIVITY_BOL_Action();

        $data = array(
            'string' => OW::getLanguage()->text('blogs', 'activity_string',
                array(
                    'user' => BOL_UserService::getInstance()->getDisplayName($this->post->getAuthorId()),
                    'userUrl' => BOL_UserService::getInstance()->getUserUrl($this->post->getAuthorId()),
                    'title' => $this->post->getTitle(),
                    'url' => OW::getRouter()->urlForRoute('post', array('id' => $this->post->getId()))
                )
            ),
            'content_comment' => ( mb_strlen($this->post->getPost()) > 30 ) ? nl2br(mb_substr($this->post->getPost(), 0, 30)) . '...' : $this->post->getPost(),
        );

        $action->setUserId($this->post->getAuthorId())
            ->setTimestamp(time())
            ->setType('blog-post-add')
            ->setEntityId($this->post->getId())
            ->setData($data);

        ACTIVITY_BOL_Service::getInstance()->addAction($action);

        //Newsfeed
        $event = new OW_Event('feed.action', array(
            'pluginKey' => 'blogs',
            'entityType' => 'blog-post',
            'entityId' => $this->post->getId(),
            'userId' => $this->post->getAuthorId()
        ));
        OW::getEventManager()->trigger($event);
        
        $ctrl->redirect(OW::getRouter()->urlForRoute('post', array('id' => $this->post->getId())));
    }
}

class BLOGS_TextFormatter extends BASE_CMP_TextFormatter
{

    public function __construct()
    {
        $dl = '<';
        $dr = '>';
        $list = array(
            array(
                'id' => 'bid',
                'label' => 'b',
                'style' => 'font-weight: bold',
                'open' => $dl . 'strong' . $dr,
                'close' => $dl . '/strong' . $dr
            ),
            array(
                'id' => 'iid',
                'label' => 'i',
                'style' => 'font-style: italic',
                'open' => $dl . 'i' . $dr,
                'close' => $dl . '/i' . $dr
            ),
            array(
                'id' => 'uid',
                'label' => 'u',
                'style' => 'text-decoration: underline',
                'open' => $dl . 'u' . $dr,
                'close' => $dl . '/u' . $dr
            ),
            array(
                'id' => 'lid',
                'label' => 'link',
                'style' => 'color: #0000FF; text-decoration:underline;',
                'open' => $dl . 'a href="#url#"' . $dr,
                'extra' =>
                array('#url#' => array(
                        'type' => 'prompt',
                        'inv' => 'Enter the URL',
                        'def' => 'http://'
                    )
                ),
                'close' => $dl . '/a' . $dr
            ),
            array(
                'id' => 'mid',
                'label' => 'more',
                'open' => '<!--more-->',
                'isPaired' => false,
            )
        );

        parent::__construct('blogs', 'ff', $dl, $dr, $list);
    }
}
?>
