<?php

/**
 * This software is intended for use with Oxwall Free Community Software http://www.oxwall.org/ and is
 * licensed under The BSD license.

 * ---
 * Copyright (c) 2009, Skalfa LLC
 * All rights reserved.

 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *  - Redistributions of source code must retain the above copyright notice, this list of conditions and
 *  the following disclaimer.
 *
 *  - Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 *  the following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *  - Neither the name of the Skalfa LLC nor the names of its contributors may be used to endorse or promote products
 *  derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
OW::getRouter()->addRoute(new OW_Route('friends_list', 'friends', 'FRIENDS_CTRL_List', 'index'));
OW::getRouter()->addRoute(new OW_Route('friends_sent_requests', 'friends/sent-requests', 'FRIENDS_CTRL_List', 'index'));
OW::getRouter()->addRoute(new OW_Route('friends_got_requests', 'friends/got-requests', 'FRIENDS_CTRL_List', 'index'));
OW::getRouter()->addRoute(new OW_Route('friends_user_friends', 'friends/user/:user', 'FRIENDS_CTRL_List', 'index'));

function friends_user_action_tool( BASE_CLASS_EventCollector $event )
{
    $params = $event->getParams();

    if ( empty($params['userId']) )
    {
        return;
    }

    $userId = (int) $params['userId'];

    if ( OW::getUser()->getId() == $userId )
    {
        return;
    }

    if ( OW::getUser()->isAuthenticated() && OW::getUser()->isAuthorized('friends', 'add_friend') )
    {
        $service = FRIENDS_BOL_Service::getInstance();

        $dto = $service->findFriendship($userId, OW::getUser()->getId());

        if ( empty($dto) )
        {
            $label = OW::getLanguage()->text('friends', 'add_to_friends');
            $href = OW::getRouter()->urlFor('FRIENDS_CTRL_Action', 'request', array('id' => $userId));
        }
        else
        {

            switch ( $dto->getStatus() )
            {
                case 'active':

                    $label = OW::getLanguage()->text('friends', 'remove_from_friends');
                    $href = OW::getRouter()->urlFor('FRIENDS_CTRL_Action', 'cancel', array('id' => $userId));

                    break;

                case 'pending':

                    $imSender = $dto->getUserId() == OW::getUser()->getId();

                    if ( $imSender )
                    {
                        $label = OW::getLanguage()->text('friends', 'remove_from_friends');
                        $href = OW::getRouter()->urlFor('FRIENDS_CTRL_Action', 'cancel', array('id' => $userId));
                        break;
                    }

                    $label = OW::getLanguage()->text('friends', 'add_to_friends');
                    $href = OW::getRouter()->urlFor('FRIENDS_CTRL_Action', 'accept', array('id' => $userId));

                    break;

                case 'ignored':

                    $imSender = $dto->getUserId() == OW::getUser()->getId();

                    if ( $imSender )
                    {
                        $label = OW::getLanguage()->text('friends', 'remove_from_friends');
                        $href = OW::getRouter()->urlFor('FRIENDS_CTRL_Action', 'cancel', array('id' => $userId));

                        break;
                    }

                    $label = OW::getLanguage()->text('friends', 'add_to_friends');
                    $href = OW::getRouter()->urlFor('FRIENDS_CTRL_Action', 'activate', array('id' => $userId));

                    break;
            }
        }

        $resultArray = array(
            BASE_CMP_ProfileActionToolbar::DATA_KEY_LABEL => $label,
            BASE_CMP_ProfileActionToolbar::DATA_KEY_LINK_HREF => $href
        );

        $event->add($resultArray);
    }
}
OW::getEventManager()->bind(BASE_CMP_ProfileActionToolbar::EVENT_NAME, 'friends_user_action_tool');

function friends_on_user_delete( OW_Event $event )
{
    $params = $event->getParams();

    $userId = $params['userId'];

    $service = FRIENDS_BOL_Service::getInstance();
    $service->deleteUserFriendships($userId);
}
OW::getEventManager()->bind(OW_EventManager::ON_USER_UNREGISTER, 'friends_on_user_delete');

//---
function friends_on_notify_actions( BASE_CLASS_EventCollector $e )
{
    $e->add(array(
        'section' => 'friends',
        'action' => 'friends-request',
        'description' => OW::getLanguage()->text('friends', 'email_notifications_setting_request'),
        'selected' => true,
        'sectionLabel' => 'Friends',
        'sectionIcon' => 'ow_ic_write'
    ));

    $e->add(array(
        'section' => 'friends',
        'action' => 'friends-accept',
        'description' => OW::getLanguage()->text('friends', 'email_notifications_setting_accept'),
        'selected' => true,
        'sectionLabel' => 'Friends',
        'sectionIcon' => 'ow_ic_write'
    ));
}
OW::getEventManager()->bind('base.notify_actions', 'friends_on_notify_actions');

//~~


function friends_ads_enabled( BASE_EventCollector $event )
{
    $event->add('friends');
}
OW::getEventManager()->bind('ads.enabled_plugins', 'friends_ads_enabled');