<?php

/**
 * This software is intended for use with Oxwall Free Community Software http://www.oxwall.org/ and is
 * licensed under The BSD license.

 * ---
 * Copyright (c) 2009, Skalfa LLC
 * All rights reserved.

 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *  - Redistributions of source code must retain the above copyright notice, this list of conditions and
 *  the following disclaimer.
 *
 *  - Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 *  the following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *  - Neither the name of the Skalfa LLC nor the names of its contributors may be used to endorse or promote products
 *  derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
$plugin = OW::getPluginManager()->getPlugin('groups');

//Admin Routs
OW::getRouter()->addRoute(new OW_Route('groups-admin-widget-panel', 'admin/plugins/groups', 'GROUPS_CTRL_Admin', 'panel'));
OW::getRouter()->addRoute(new OW_Route('groups-admin-additional-features', 'admin/plugins/groups/additional', 'GROUPS_CTRL_Admin', 'additional'));
OW::getRouter()->addRoute(new OW_Route('groups-admin-uninstall', 'admin/plugins/groups/uninstall', 'GROUPS_CTRL_Admin', 'uninstall'));

//Frontend Routs
OW::getRouter()->addRoute(new OW_Route('groups-create', 'groups/create', 'GROUPS_CTRL_Groups', 'create'));
OW::getRouter()->addRoute(new OW_Route('groups-edit', 'groups/:groupId/edit', 'GROUPS_CTRL_Groups', 'edit'));
OW::getRouter()->addRoute(new OW_Route('groups-view', 'groups/:groupId', 'GROUPS_CTRL_Groups', 'view'));
OW::getRouter()->addRoute(new OW_Route('groups-join', 'groups/:groupId/join', 'GROUPS_CTRL_Groups', 'join'));
OW::getRouter()->addRoute(new OW_Route('groups-customize', 'groups/:groupId/customize', 'GROUPS_CTRL_Groups', 'customize'));
OW::getRouter()->addRoute(new OW_Route('groups-most-popular', 'groups/most-popular', 'GROUPS_CTRL_Groups', 'mostPopularList'));
OW::getRouter()->addRoute(new OW_Route('groups-latest', 'groups/latest', 'GROUPS_CTRL_Groups', 'latestList'));
OW::getRouter()->addRoute(new OW_Route('groups-index', 'groups', 'GROUPS_CTRL_Groups', 'index'));
OW::getRouter()->addRoute(new OW_Route('groups-user-groups', 'users/:user/groups', 'GROUPS_CTRL_Groups', 'userGroupList'));
OW::getRouter()->addRoute(new OW_Route('groups-leave', 'groups/:groupId/leave', 'GROUPS_CTRL_Groups', 'leave'));

OW::getRouter()->addRoute(new OW_Route('groups-user-list', 'groups/:groupId/users', 'GROUPS_CTRL_Groups', 'userList'));

OW::getRegistry()->addToArray(BASE_CMP_AddNewContent::REGISTRY_DATA_KEY,
    array(
        BASE_CMP_AddNewContent::DATA_KEY_ICON_CLASS => 'ow_ic_comment',
        BASE_CMP_AddNewContent::DATA_KEY_URL => OW::getRouter()->urlForRoute('groups-create'),
        BASE_CMP_AddNewContent::DATA_KEY_LABEL => OW::getLanguage()->text('groups', 'add_new_label')
));

function groups_on_add_new_content( BASE_CLASS_EventCollector $event )
{
    $event->add(array(
        BASE_CMP_AddNewContent::DATA_KEY_ICON_CLASS => 'ow_ic_comment',
        BASE_CMP_AddNewContent::DATA_KEY_URL => OW::getRouter()->urlForRoute('groups-create'),
        BASE_CMP_AddNewContent::DATA_KEY_LABEL => OW::getLanguage()->text('groups', 'add_new_label')
    ));
}
OW::getEventManager()->bind(BASE_CMP_AddNewContent::EVENT_NAME, 'groups_on_add_new_content');

/* Events */

function groups_delete_on_group( OW_Event $event )
{
    $params = $event->getParams();
    $groupId = $params['groupId'];

    $group = GROUPS_BOL_Service::getInstance()->findGroupById($groupId);
    $fileName = GROUPS_BOL_Service::getInstance()->getGroupImagePath($group);

    if ( $fileName !== null )
    {
        OW::getStorage()->removeFile($fileName);
    }
}
OW::getEventManager()->bind(GROUPS_BOL_Service::EVENT_ON_DELETE, 'groups_delete_on_group');

function groups_delete_group_complete( OW_Event $event )
{
    $params = $event->getParams();

    $groupId = $params['groupId'];

    BOL_ComponentEntityService::getInstance()->onEntityDelete(GROUPS_BOL_Service::WIDGET_PANEL_NAME, $groupId);
    BOL_CommentService::getInstance()->deleteEntityComments(GROUPS_BOL_Service::ENTITY_TYPE_WAL, $groupId);

    BOL_FlagService::getInstance()->deleteByTypeAndEntityId(GROUPS_BOL_Service::ENTITY_TYPE_GROUP, $groupId);

    if ( OW::getPluginManager()->isPluginActive('activity') )
    {
        ACTIVITY_BOL_Service::getInstance()->deleteAction(null, 'groups-add', $groupId);
        ACTIVITY_BOL_Service::getInstance()->deleteAction(null, 'groups-join', $groupId);
    }
}
OW::getEventManager()->bind(GROUPS_BOL_Service::EVENT_DELETE_COMPLETE, 'groups_delete_group_complete');

function groups_on_user_unregister( OW_Event $event )
{
    $params = $event->getParams();

    $userId = (int) $params['userId'];
    $groups = GROUPS_BOL_Service::getInstance()->findUserGroupList($userId);

    foreach ( $groups as $groups )
    {
        GROUPS_BOL_Service::getInstance()->deleteGroup($groups->id);
    }
}
OW::getEventManager()->bind(OW_EventManager::ON_USER_UNREGISTER, 'groups_on_user_unregister');

function groups_on_notify_actions( BASE_CLASS_EventCollector $e )
{
    $e->add(array(
        'section' => 'groups',
        'sectionIcon' => 'ow_ic_files',
        'sectionLabel' => OW::getLanguage()->text('groups', 'email_notification_section_label'),
        'action' => 'groups-add_comment',
        'description' => OW::getLanguage()->text('groups', 'email_notification_comment_setting')
    ));
}
OW::getEventManager()->bind('base.notify_actions', 'groups_on_notify_actions');

function groups_add_comment( OW_Event $e )
{
    $params = $e->getParams();

    if ( empty($params['entityType']) || $params['entityType'] != GROUPS_BOL_Service::ENTITY_TYPE_WAL )
    {
        return;
    }

    $entityId = $params['entityId'];
    $userId = $params['userId'];
    $commentId = $params['commentId'];
    $group = GROUPS_BOL_Service::getInstance()->findGroupById($entityId);

    $comment = BOL_CommentService::getInstance()->findComment($commentId);
    $groupUrl = OW::getRouter()->urlForRoute('groups-view', array('groupId' => $group->id));

    $groupImage = GROUPS_BOL_Service::getInstance()->getGroupImageUrl($group);

    $string = OW::getLanguage()->text('groups', 'email_notification_comment', array(
            'userName' => BOL_UserService::getInstance()->getDisplayName($userId),
            'userUrl' => BOL_UserService::getInstance()->getUserUrl($userId),
            'url' => $groupUrl,
            'title' => strip_tags($group->title)
        ));

    $params = array(
        'plugin' => 'groups',
        'action' => 'groups-add_comment',
        'string' => $string,
        'avatar' => $groupImage,
        'content' => $comment->getMessage(),
        'url' => $groupUrl,
        'time' => time()
    );

    $userIds = GROUPS_BOL_Service::getInstance()->findGroupUserIdList($group->id);

    foreach ( $userIds as $uid )
    {
        if ( $uid == $userId )
        {
            continue;
        }

        $params['userId'] = $uid;

        $event = new OW_Event('base.notify', $params);
        OW::getEventManager()->trigger($event);
    }
}
OW::getEventManager()->bind('base_add_comment', 'groups_add_comment');

function groups_on_group_create_activity( OW_Event $e )
{
    $params = $e->getParams();

    $groupId = (int) $params['groupId'];

    if ( !OW::getPluginManager()->isPluginActive('activity') )
    {
        return;
    }

    $activityService = ACTIVITY_BOL_Service::getInstance();
    $groupService = GROUPS_BOL_Service::getInstance();


    $group = $groupService->findGroupById($groupId);
    $thumbnail = $groupService->getGroupImageUrl($group);
    $url = $groupService->getGroupUrl($group);

    $data = array(
        'string' => OW::getLanguage()->text('groups', 'activity_add_string',
            array(
                'user' => BOL_UserService::getInstance()->getDisplayName($group->userId),
                'userUrl' => BOL_UserService::getInstance()->getUserUrl($group->userId),
                'groupTitle' => mb_substr(strip_tags($group->title), 0, 100),
                'groupUrl' => $url
            )
        ),
        'content' => '<a href="' . $url . '"><img src="' . $thumbnail . '" height="80" /></a>',
        'content_comment' => $group->description
    );

    $action = new ACTIVITY_BOL_Action();

    $action->setUserId($group->userId)
        ->setTimestamp(time())
        ->setType('groups-add')
        ->setEntityId($group->id)
        ->setData($data);

    ACTIVITY_BOL_Service::getInstance()->addAction($action);
}
OW::getEventManager()->bind(GROUPS_BOL_Service::EVENT_CREATE, 'groups_on_group_create_activity');

function groups_on_group_join_activity( OW_Event $e )
{
    $params = $e->getParams();

    $groupId = (int) $params['groupId'];
    $userId = (int) $params['userId'];

    if ( !OW::getPluginManager()->isPluginActive('activity') )
    {
        return;
    }

    $activityService = ACTIVITY_BOL_Service::getInstance();
    $groupService = GROUPS_BOL_Service::getInstance();

    $group = $groupService->findGroupById($groupId);

    if ( $group->userId == $userId )
    {
        return;
    }

    $thumbnail = $groupService->getGroupImageUrl($group);
    $url = $groupService->getGroupUrl($group);

    $data = array(
        'string' => OW::getLanguage()->text('groups', 'activity_join_string',
            array(
                'user' => BOL_UserService::getInstance()->getDisplayName($userId),
                'userUrl' => BOL_UserService::getInstance()->getUserUrl($userId),
                'groupTitle' => mb_substr(strip_tags($group->title), 0, 100),
                'groupUrl' => $url
            )
        ),
        'content' => '<a href="' . $url . '"><img src="' . $thumbnail . '" height="80" /></a>',
        'content_comment' => $group->description
    );

    $action = new ACTIVITY_BOL_Action();

    $action->setUserId($group->userId)
        ->setTimestamp(time())
        ->setType('groups-join')
        ->setEntityId($group->id)
        ->setData($data);

    ACTIVITY_BOL_Service::getInstance()->addAction($action);
}
OW::getEventManager()->bind(GROUPS_BOL_Service::EVENT_USER_ADDED, 'groups_on_group_join_activity');

function groups_check_permissions( OW_Event $event )
{
    $params = $event->getParams();

    if ( !isset($params['entityId']) || !isset($params['entity']) )
    {
        return;
    }

    if ( $params['entity'] == 'groups' )
    {
        $groupService = GROUPS_BOL_Service::getInstance();

        if ( $groupService->findUser($params['entityId'], OW::getUser()->getId()) )
        {
            $event->setData(true);
        }
        else
        {
            $event->setData(false);
        }
    }
}
OW::getEventManager()->bind('forum.check_permissions', 'groups_check_permissions');

function groups_on_find_forum_caption( OW_Event $event )
{

    $params = $event->getParams();
    if ( !isset($params['entity']) || !isset($params['entityId']) )
    {
        return;
    }

    if ( $params['entity'] == 'groups' )
    {
        $component = new GROUPS_CMP_BriefInfo($params['entityId']);
        $eventData['component'] = $component;
        $eventData['key'] = 'main_menu_list';
        $event->setData($eventData);
    }
}
OW::getEventManager()->bind('forum.find_forum_caption', 'groups_on_find_forum_caption');

function groups_is_forum_active( BASE_CLASS_EventCollector $event )
{
    $is_forum_connected = OW::getConfig()->getValue('groups', 'is_forum_connected');

    if ( $is_forum_connected && !OW::getPluginManager()->isPluginActive('forum') )
    {
        $language = OW::getLanguage();

        $event->add($language->text('groups', 'error_forum_disconnected', array('url' => OW::getRouter()->urlForRoute('admin_plugins_installed'))));
    }
}
OW::getEventManager()->bind('admin.add_admin_notification', 'groups_is_forum_active');

function groups_uninstall_forum_plugin( OW_Event $event )
{
    $config = OW::getConfig();

    if ( $config->getValue('groups', 'is_forum_connected') )
    {
        $event = new OW_Event('forum.delete_section', array('entity' => 'groups'));
        OW::getEventManager()->trigger($event);

        $event = new OW_Event('forum.delete_widget');
        OW::getEventManager()->trigger($event);

        $config->saveConfig('groups', 'is_forum_connected', 0);

        $actionId = BOL_AuthorizationActionDao::getInstance()->getIdByName('add_topic');

        BOL_AuthorizationService::getInstance()->deleteAction($actionId);
    }
}
OW::getEventManager()->bind('forum.uninstall_plugin', 'groups_uninstall_forum_plugin');

function groups_activate_forum_plugin( OW_Event $event )
{
    $is_forum_connected = OW::getConfig()->getValue('groups', 'is_forum_connected');

    // Add latest topic widget if forum plugin is connected
    if ( $is_forum_connected )
    {
        $event->setData(array('forum_connected' => true, 'place' => 'group', 'section' => BOL_ComponentAdminService::SECTION_RIGHT));
    }
}
OW::getEventManager()->bind('forum.activate_plugin', 'groups_activate_forum_plugin');


//Feed
function groups_after_group_create( OW_Event $event )
{
    $params = $event->getParams();
    $groupId = (int) $params['groupId'];
    
    $event = new OW_Event('feed.action', array(
        'entityType' => GROUPS_BOL_Service::ENTITY_TYPE_WAL,
        'entityId' => $groupId,
        'pluginKey' => 'groups'
    ), $data);
    
    OW::getEventManager()->trigger($event);
}
OW::getEventManager()->bind(GROUPS_BOL_Service::EVENT_CREATE, 'groups_after_group_create');

function groups_feed_on_entity_add( OW_Event $e )
{
    $params = $e->getParams();
    $data = $e->getData();
    
    if ( $params['entityType'] != GROUPS_BOL_Service::ENTITY_TYPE_WAL )
    {
        return;
    }
    
    $groupId = (int) $params['entityId'];
    $groupService = GROUPS_BOL_Service::getInstance();
    $group = $groupService->findGroupById($groupId);

    if ( $group === null )
    {
        return;
    }
    
    $data['params']['feedId'] = $groupId;
    $data['params']['feedType'] = 'groups';

    $thumbnail = $groupService->getGroupImageUrl($group);
    $url = $groupService->getGroupUrl($group);
    
    $content = UTIL_String::truncate(strip_tags($group->description), 150, '...');
    $title = UTIL_String::truncate(strip_tags($group->title), 100, '...');
    
    $data = array(
        'ownerId' => $group->userId,
        'time' => (int) $group->timeStamp,
        'string' => OW::getLanguage()->text('groups', 'feed_create_string'),
        'content' => '<div class="clearfix"><div class="ow_left" style="width: 100px; margin-right: -100px;">
            <a href="' . $url . '"><img src="' . $thumbnail . '" /></a>
        </div><div style="margin-left: 105px;">
        <a href="' . $url . '">' . $title . '</a><div class="ow_remark">' . $content . '</div></div></div>',
        'view' => array(
            'iconClass' => 'ow_ic_files'
        )
    );
    
    $e->setData($data);
}
OW::getEventManager()->bind('feed.on_entity_add', 'groups_feed_on_entity_add');

function groups_feed_on_user_join( OW_Event $e )
{
    $params = $e->getParams();
    
    $groupId = (int) $params['groupId'];
    $userId = (int) $params['userId'];

    $groupService = GROUPS_BOL_Service::getInstance();
    $group = $groupService->findGroupById($groupId);
    
    if ( $group->userId == $userId )
    {
        return;
    }
    
    $thumbnail = $groupService->getGroupImageUrl($group);
    $url = $groupService->getGroupUrl($group);
    $content = UTIL_String::truncate(strip_tags($group->description), 150, '...');
    $title = UTIL_String::truncate(strip_tags($group->title), 100, '...');
    
    $data = array(
        'time' => time(),
        'string' => OW::getLanguage()->text('groups', 'feed_join_string',
            array(
                'groupTitle' => $title,
                'groupUrl' => $url
            )
        ),
        'content' => '<div class="clearfix"><div class="ow_left" style="width: 100px; margin-right: -100px;">
            <a href="' . $url . '"><img src="' . $thumbnail . '" /></a>
            </div><div style="margin-left: 105px;">
            <a href="' . $url . '">' . $title . '</a><div class="ow_remark">' . $content . '</div></div></div>',
        'view' => array(
            'iconClass' => 'ow_ic_add'
        )
    );
    
    $data['params']['feedId'] = $groupId;
    $data['params']['feedType'] = 'groups';
    
    $event = new OW_Event('feed.action', array(
        'entityType' => 'groups-join',
        'entityId' => $userId,
        'pluginKey' => 'groups',
        'replace' => true
    ), $data);
    
    OW::getEventManager()->trigger($event);
}
OW::getEventManager()->bind(GROUPS_BOL_Service::EVENT_USER_ADDED, 'groups_feed_on_user_join');

function groups_newsfeed_collect_widgets( BASE_CLASS_EventCollector $e )
{
    $e->add(array(
        'place' => 'group',
        'section' => BOL_ComponentService::SECTION_RIGHT,
        'order' => 0
    ));
}
OW::getEventManager()->bind('feed.collect_widgets', 'groups_newsfeed_collect_widgets');


function groups_newsfeed_on_widget_construct( OW_Event $e )
{
    $params = $e->getParams();
    
    if ( $params['feedType'] != 'groups' )
    {
        return;    
    }
    
    $groupId = (int) $params['feedId'];
    $userId = OW::getUser()->getId();
    $data = $e->getData();
    
    $userDto = GROUPS_BOL_Service::getInstance()->findUser($groupId, $userId);
    $data['statusForm'] = $userDto !== null; 
     
    $e->setData($data);
}
OW::getEventManager()->bind('feed.on_widget_construct', 'groups_newsfeed_on_widget_construct');

function groups_on_toolbar_collect( BASE_CLASS_EventCollector $e )
{
    if ( !OW::getUser()->isAuthenticated() )
    {
        return;
    }
    
    $params = $e->getParams();
    $backUri = OW::getRequest()->getRequestUri();
    
    if ( OW::getEventManager()->call('feed.is_inited') )
    {
        $url = OW::getRouter()->urlFor('GROUPS_CTRL_Groups', 'follow');
        
        $eventParams = array(
            'userId' => OW::getUser()->getId(),
            'feedType' => GROUPS_BOL_Service::ENTITY_TYPE_GROUP,
            'feedId' => $params['groupId']
        );
        
        if ( !OW::getEventManager()->call('feed.is_follow', $eventParams) )
        {
            $e->add(array(
                'label' => OW::getLanguage()->text('groups', 'feed_group_follow'),
                'href' => OW::getRequest()->buildUrlQueryString($url, array(
                    'backUri' => $backUri, 
                    'groupId' => $params['groupId'], 
                    'command' => 'follow'))
            ));
        }
        else
        {
            $e->add(array(
                'label' => OW::getLanguage()->text('groups', 'feed_group_unfollow'),
                'href' => OW::getRequest()->buildUrlQueryString($url, array(
                    'backUri' => $backUri, 
                    'groupId' => $params['groupId'], 
                    'command' => 'unfollow'))
            ));
        }
    }
}
OW::getEventManager()->bind('groups.on_toolbar_collect', 'groups_on_toolbar_collect');

function groups_ads_enabled( BASE_EventCollector $event )
{
    $event->add('groups');
}

OW::getEventManager()->bind('ads.enabled_plugins', 'groups_ads_enabled');