<?php

/**
 * EXHIBIT A. Common Public Attribution License Version 1.0
 * The contents of this file are subject to the Common Public Attribution License Version 1.0 (the “License”);
 * you may not use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.oxwall.org/license.php. The License is based on the Mozilla Public License Version 1.1
 * but Sections 14 and 15 have been added to cover use of software over a computer network and provide for
 * limited attribution for the Original Developer. In addition, Exhibit A has been modified to be consistent
 * with Exhibit B. Software distributed under the License is distributed on an “AS IS” basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for the specific language
 * governing rights and limitations under the License. The Original Code is Oxwall software.
 * The Initial Developer of the Original Code is Skalfa LLC (http://www.skalfa.com/).
 * All portions of the code written by Skalfa LLC are Copyright (c) 2009. All Rights Reserved.

 * EXHIBIT B. Attribution Information
 * Attribution Copyright Notice: Copyright 2009 Skalfa LLC. All rights reserved.
 * Attribution Phrase (not exceeding 10 words): Powered by Oxwall community software
 * Attribution URL: http://www.oxwall.org/
 * Graphic Image as provided in the Covered Code.
 * Display of Attribution Information is required in Larger Works which are defined in the CPAL as a work
 * which combines Covered Code or portions thereof with code not governed by the terms of the CPAL.
 */

/**
 * User console component class.
 *
 * @author Sardar Madumarov <madumarov@gmail.com>
 * @package ow_system_plugins.base.components
 * @since 1.0
 */
class BASE_CMP_Console extends OW_Component
{
    /**
     * Constructor.
     */
    public function __construct()
    {
        parent::__construct();

        if ( OW::getUser()->isAuthenticated() )
        {
            $this->member();
        }
        else
        {
            $this->guest();
        }

        $this->addComponent('switchLanguage', new BASE_CMP_SwitchLanguage());
    }

    private function guest()
    {
        $this->addComponent('sign_in', new BASE_CMP_AjaxSignIn());
        $this->addComponent('connectButtonList', new BASE_CMP_ConnectButtonList());
    }

    private function member()
    { //TODO total refactor -> shared registry
        $this->setTemplate(OW::getPluginManager()->getPlugin('base')->getCmpViewDir() . 'console_member.html');

        $language = OW::getLanguage();

        $router = OW::getRouter();

        $links = array(
            'dashbord' => $router->urlForRoute('base_member_dashboard'),
            'profile' => $router->urlForRoute('base_member_profile'),
            'sign_out' => $router->urlForRoute('base_sign_out')
        );

        $event = new BASE_CLASS_EventCollector('base.console_item_collector');
        OW::getEventManager()->trigger($event);
        $data = $event->getData();
        $this->assign('items', implode('', $data));
        
        try
        {
            OW::getPluginManager()->getPlugin('mailbox');

            $mailsCount = MAILBOX_BOL_ConversationService::getInstance()->getNewInboxConversationCount(OW::getUser()->getId());

            $links['mailbox'] = $router->urlForRoute('mailbox_default');

            if ( $mailsCount > 0 )
            {
                $this->assign('new_mail', array('href' => $router->urlForRoute('mailbox_default'), 'count' => $mailsCount));
            }
        }
        catch ( Exception $e )
        {

        }

        if( OW::getPluginManager()->isPluginActive('friends') ) // todo: 8aa refact with registry
        {
            OW::getPluginManager()->getPlugin('friends');

            $count = FRIENDS_BOL_Service::getInstance()->count(null, OW::getUser()->getId(), FRIENDS_BOL_Service::STATUS_PENDING);

            if ( $count > 0 )
            {
                $this->assign('friends', array('href' => OW::getRouter()->urlForRoute('friends_got_requests'), 'count' => $count));
            }
        }

        $displayName = BOL_UserService::getInstance()->getDisplayName(OW::getUser()->getId());
        $this->assign('displayName', $displayName);

        $this->assign('links', $links);

        $this->assign('titles', array(
            'dashbord' => $language->text('base', 'console_item_label_dashboard'),
            'pref' => $language->text('base', 'console_item_label_preferences'),
            'profile' => $language->text('base', 'console_item_label_profile'),
            'mailbox' => $language->text('base', 'console_item_label_mailbox'),
            'sign_out' => $language->text('base', 'console_item_label_sign_out')
        ));
    }
}