<?php

/**
 * EXHIBIT A. Common Public Attribution License Version 1.0
 * The contents of this file are subject to the Common Public Attribution License Version 1.0 (the “License”);
 * you may not use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.oxwall.org/license.php. The License is based on the Mozilla Public License Version 1.1
 * but Sections 14 and 15 have been added to cover use of software over a computer network and provide for
 * limited attribution for the Original Developer. In addition, Exhibit A has been modified to be consistent
 * with Exhibit B. Software distributed under the License is distributed on an “AS IS” basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for the specific language
 * governing rights and limitations under the License. The Original Code is Oxwall software.
 * The Initial Developer of the Original Code is Skalfa LLC (http://www.skalfa.com/).
 * All portions of the code written by Skalfa LLC are Copyright (c) 2009. All Rights Reserved.

 * EXHIBIT B. Attribution Information
 * Attribution Copyright Notice: Copyright 2009 Skalfa LLC. All rights reserved.
 * Attribution Phrase (not exceeding 10 words): Powered by Oxwall community software
 * Attribution URL: http://www.oxwall.org/
 * Graphic Image as provided in the Covered Code.
 * Display of Attribution Information is required in Larger Works which are defined in the CPAL as a work
 * which combines Covered Code or portions thereof with code not governed by the terms of the CPAL.
 */

/**
 * @author Aybat Duyshokov <duyshokov@gmail.com>
 * @package ow_system_plugins.base.components
 * @since 1.0
 */
class BASE_CMP_UserListWidget extends BASE_CMP_UsersWidget
{

    public function getData( $count )
    {
        $language = OW::getLanguage();
        $userService = BOL_UserService::getInstance();

        $toolbar = self::getToolbar();

        return array(
            array(
                'key' => 'latest',
                'menu-label' => $language->text('base', 'user_list_menu_item_latest'),
                'menu_active' => true,
                'users' => $userService->findList(0, $count),
                'toolbar' => $toolbar['latest'][0],
            ),
            array(
                'key' => 'online',
                'menu-label' => $language->text('base', 'user_list_menu_item_online'),
                'users' => $userService->findOnlineList(0, $count),
                'toolbar' => $toolbar['online'][0],
            ),
            array(
                'key' => 'featured',
                'menu-label' => $language->text('base', 'user_list_menu_item_featured'),
                'users' => $userService->findFeaturedList(0, $count),
                'toolbar' => $toolbar['featured'][0],
            ),
        );
    }

    public static function getToolbar()
    {
        return array(
            'latest' => array(
                array(
                    'label' => OW::getLanguage()->text('base', 'view_all'),
                    'href' => OW::getRouter()->urlForRoute('users_latest')
                )
            ),
            'online' => array(
                array(
                    'label' => OW::getLanguage()->text('base', 'view_all'),
                    'href' => OW::getRouter()->urlForRoute('users_online')
                )
            ),
            'featured' => array(
                array(
                    'label' => OW::getLanguage()->text('base', 'view_all'),
                    'href' => OW::getRouter()->urlForRoute('users_featured')
                )
            ),
        );
    }

    public static function getSettingList()
    {
        $settingList = array();
        $settingList['count'] = array(
            'presentation' => 'number',
            'label' => 'Count',
            'value' => '10'
        );

        return $settingList;
    }

    public static function getStandardSettingValueList()
    {
        $toolbars = self::getToolbar();
        return array(
            self::SETTING_TITLE => 'Users',
            self::SETTING_TOOLBAR => $toolbars['latest']
        );
    }

    public static function getAccess()
    {
        return self::ACCESS_ALL;
    }
}