<?php

/**
 * EXHIBIT A. Common Public Attribution License Version 1.0
 * The contents of this file are subject to the Common Public Attribution License Version 1.0 (the “License”);
 * you may not use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.oxwall.org/license.php. The License is based on the Mozilla Public License Version 1.1
 * but Sections 14 and 15 have been added to cover use of software over a computer network and provide for
 * limited attribution for the Original Developer. In addition, Exhibit A has been modified to be consistent
 * with Exhibit B. Software distributed under the License is distributed on an “AS IS” basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for the specific language
 * governing rights and limitations under the License. The Original Code is Oxwall software.
 * The Initial Developer of the Original Code is Skalfa LLC (http://www.skalfa.com/).
 * All portions of the code written by Skalfa LLC are Copyright (c) 2009. All Rights Reserved.

 * EXHIBIT B. Attribution Information
 * Attribution Copyright Notice: Copyright 2009 Skalfa LLC. All rights reserved.
 * Attribution Phrase (not exceeding 10 words): Powered by Oxwall community software
 * Attribution URL: http://www.oxwall.org/
 * Graphic Image as provided in the Covered Code.
 * Display of Attribution Information is required in Larger Works which are defined in the CPAL as a work
 * which combines Covered Code or portions thereof with code not governed by the terms of the CPAL.
 */

/**
 * @package ow_system_plugins.base.controllers
 * @since 1.0
 */
class BASE_CTRL_UserList extends OW_ActionController
{

    public function __construct()
    {
        parent::__construct();

        @OW::getNavigation()->activateMenuItem(OW_Navigation::MAIN, 'base', 'users_main_menu_item');

        $this->setPageHeading(OW::getLanguage()->text('base', 'users_browse_page_heading'));
        $this->setPageHeadingIconClass('ow_ic_user');
    }

    public function index()
    {
        $language = OW::getLanguage();

        $this->addComponent('menu', self::getMenu());

        $page = (!empty($_GET['page']) && intval($_GET['page']) > 0 ) ? $_GET['page'] : 1;

        $rpp = 30;
        $first = ($page - 1) * $rpp;
        $count = $rpp;

        list($list, $itemCount) = $this->getData($first, $count);

        $cmp = new BASE_Members($list, $itemCount, $rpp, !in_array($this->getCase(), array('online', 'birthdays')));

        $this->addComponent('cmp', $cmp);
    }

    public function forApproval()
    {
        $this->setTemplate(OW::getPluginManager()->getPlugin('base')->getCtrlViewDir() . 'user_list_index.html');

        $language = OW::getLanguage();

        $page = (!empty($_GET['page']) && intval($_GET['page']) > 0 ) ? $_GET['page'] : 1;

        $rpp = 30;
        $first = ($page - 1) * $rpp;
        $count = $rpp;

        list($list, $itemCount) = $this->getData($first, $count);

        $cmp = new BASE_Members($list, $itemCount, $rpp, $this->getCase() != 'online');

        $this->addComponent('cmp', $cmp);
    }

    private function getData( $first, $count )
    {
        $service = BOL_UserService::getInstance();

        
        
        switch ( $this->getCase() )
        {
            case 'latest':
                return array(
                    $service->findList($first, $count),
                    $service->count()
                );

            case 'waiting-for-approval':
                return array(
                    $service->findDisapprovedList($first, $count),
                    $service->countDisapproved(),
                );

            case 'online':

                return array(
                    $service->findOnlineList($first, $count),
                    $service->countOnline()
                );

            case 'featured':

                return array(
                    $service->findFeaturedList($first, $count),
                    $service->countFeatured()
                );

            default:
                $pluginData = OW::getRegistry()->getArray('users_page_data');
                
                foreach($pluginData as $data)
                {
                    if($data->getCase() == $this->getCase())
                        return $data->getData($first, $count);    
                }

                return array(array(), 0);
        }

    }

    public static function getMenu()
    {
        $language = OW::getLanguage();

        $case = self::getCase();

        $item[0] = new BASE_MenuItem();

        $item[0]->setLabel($language->text('base', 'user_list_menu_item_latest'))
            ->setKey('1')
            ->setUrl(OW::getRouter()
                ->urlForRoute('users_latest'))
            ->setOrder(1)
            ->setIconClass('ow_ic_clock');

        $case = self::getCase();

        if ( $case == 'latest' )
        {
            $item[0]->setActive(true);
        }
//--
        $item[1] = new BASE_MenuItem();

        $item[1]->setLabel($language->text('base', 'user_list_menu_item_featured'))
            ->setKey('2')
            ->setUrl(OW::getRouter()
                ->urlForRoute('users_featured'))
            ->setOrder(2)
            ->setIconClass('ow_ic_push_pin');

        if ( $case == 'featured' )
        {
            $item[1]->setActive(true);
        }
//--
        $item[2] = new BASE_MenuItem();

        $item[2]->setLabel($language->text('base', 'user_list_menu_item_online'))
            ->setKey('3')
            ->setUrl(OW::getRouter()
                ->urlForRoute('users_online'))
            ->setOrder(3)
            ->setIconClass('ow_ic_push_pin');


        if ( $case == 'online' )
        {
            $item[2]->setActive(true);
        }


        $item[3] = new BASE_MenuItem();

        $item[3]->setLabel($language->text('base', 'user_search_menu_item_label'))
            ->setKey('search')
            ->setUrl(OW::getRouter()
                ->urlForRoute('users-search'))
            ->setOrder(4)
            ->setIconClass('ow_ic_lens');

        if ( $case == 'users-search' )
        {
            $item[3]->setActive(true);
        }

        $pluginData = OW::getRegistry()->getArray('users_page_data');
        
        foreach($pluginData as $data)
        {
            $item[] = $data->getMenuItem();            
        }

        return new BASE_CMP_ContentMenu($item);
    }

    public static function getCase()
    {
        if ( count($_GET) )
        {
            $arr = explode('?', OW::getRequest()->getRequestUri());
        }

        if (
            (!empty($arr)
            && in_array(
                trim($arr[0]),
                array(
                    OW::getRouter()->uriForRoute('users'),
                    OW::getRouter()->uriForRoute('users') . '/'
                )
            )
            )
            || OW::getRequest()->getRequestUri() == OW::getRouter()->uriForRoute('users')
            || false !== strstr(OW::getRequest()->getRequestUri(), OW::getRouter()->uriForRoute('users_latest'))
        )
            return 'latest';

        if ( false !== strstr(OW::getRequest()->getRequestUri(), OW::getRouter()->uriForRoute('users_featured')) )
            return 'featured';

        if ( false !== strstr(OW::getRequest()->getRequestUri(), OW::getRouter()->uriForRoute('users_online')) )
            return 'online';

        if ( false !== strstr(OW::getRequest()->getRequestUri(), OW::getRouter()->uriForRoute('users-waiting-for-approval')) )
            return 'waiting-for-approval';

        if ( false !== strstr(OW::getRequest()->getRequestUri(), OW::getRouter()->uriForRoute('users-search')) )
            return 'users-search';
            
        $pluginData = OW::getRegistry()->getArray('users_page_data');
        
        foreach($pluginData as $data)
        {
            if($data->isCase())
                return $data->getCase();
        }
    }
}

class BASE_Members extends BASE_CMP_Users
{

    public function getFields( $userIdList )
    {
        $fields = array();

        $qs = array();

        $qBdate = BOL_QuestionService::getInstance()->findQuestionByName('birthdate', 'sex');

        if ( $qBdate->onView )
            $qs[] = 'birthdate';

        $qSex = BOL_QuestionService::getInstance()->findQuestionByName('sex');

        if ( $qSex->onView )
            $qs[] = 'sex';

        $questionList = BOL_QuestionService::getInstance()->getQuestionData($userIdList, $qs);

        foreach ( $questionList as $uid => $q )
        {

            $fields[$uid] = array();

            $age = '';

            if( !empty($q['birthdate']) )
            {
                $date = UTIL_DateTime::parseDate($q['birthdate'], UTIL_DateTime::MYSQL_DATETIME_DATE_FORMAT);
    
                $age = UTIL_DateTime::getAge($date['year'], $date['month'], $date['day']);
            }

            if ( !empty($q['sex']) )
            {
                $fields[$uid][] = array(
                    'label' => '',
                    'value' => BOL_QuestionService::getInstance()->getQuestionValueLang('sex', $q['sex']) . ' ' . $age
                );
            }

            if( !empty($q['birthdate']) )
            {
                $dinfo = date_parse($q['birthdate']);
                
                if ( BASE_CTRL_UserList::getCase() == 'birthdays' )
                {
                    $birthdate = '';
    
                    if ( intval(date('d')) + 1 == intval($dinfo['day']) )
                    {
                        $questionList[$uid]['birthday'] = OW::getLanguage()->text('base', 'date_time_tomorrow');
    
                        $birthdate = '<a href="#" class="ow_lbutton ow_green">' . $questionList[$uid]['birthday'] . '</a>';
                    }
                    else if ( intval(date('d')) == intval($dinfo['day']) )
                    {
                        $questionList[$uid]['birthday'] = OW::getLanguage()->text('base', 'date_time_today');
    
                        $birthdate = '<a href="#" class="ow_lbutton ow_green">' . $questionList[$uid]['birthday'] . '</a>';
                    }
                    else
                    {
                        $birthdate = UTIL_DateTime::formatBirthdate($dinfo['year'], $dinfo['month'], $dinfo['day']);    
                    }
    
                    $fields[$uid][] = array(
                        'label' => 'Birthday: ',
                        'value' => $birthdate
                    );
                    
                }
            }
        }

        return $fields;
    }
}